/**/
#include <stdio.h>
#include <math.h>

int main() {

float num1,num2,num3,num4; //**/
float score; //**/

printf("Enter thresholds for A, B, C, D\nin that order, decreasing percentages > ");
scanf("%f%f%f%f",&num1,&num2,&num3,&num4);

printf("Thank you. Now enter student score (percent) >");
scanf("%f",&score);

printf("Student has an A grade");

printf("%f%f%f%f%f", num1,num2,num3,num4,score);

return 0;
}
